==============================================================================
:mod:`xoutil.eight` -- Extensions for writing code that runs on Python 2 and 3
==============================================================================

.. automodule:: xoutil.eight
   :members:


Tools
=====

.. automodule:: xoutil.eight.meta
   :members: metaclass


.. automodule:: xoutil.eight.types
   :members: DictProxyType, MemberDescriptorType, NoneType, MappingProxyType,
             SimpleNamespace, DynamicClassAttribute, new_class, prepare_class


.. automodule:: xoutil.eight.io
   :members: is_file_like

.. automodule:: xoutil.eight.exceptions
   :members: reraise


.. automodule:: xoutil.eight.abc
